#!/usr/bin/python2
# -*- coding: utf-8 -*-

import socket
import sys
import threading
import time
import paramiko
from pprint import pprint

class SecureShell(paramiko.SSHClient):
	def __init__(self, host, user='logicube', passwd='logicube'):
		self.host = host
		self.user = user
		self.passwd = passwd
		super(SecureShell, self).__init__()
		self.load_system_host_keys()
		self.set_missing_host_key_policy(paramiko.AutoAddPolicy())

	def Login(self):
		try:
			self.connect(self.host, 22, self.user, self.passwd, timeout=5, banner_timeout=5)
		except paramiko.AuthenticationException:
			pprint("Authentication Failed! host={0}".format(self.host))
			pprint("Please check username and password")
			return False

		except paramiko.SSHException:
			pprint("Failed to connect host={0}".format(self.host))
			pprint("Make sure hostname is correct and that it is up and running")
			return False

		except Exception as e:
			pprint("Failed to connect host={0} - {1}".format(self.host, str(e)))
			return False
		return True

	def Do(self, cmd='', res=None):
		try:
			if not self.get_transport().is_active():
				pprint("SSH connection to '{0}' not active".format(self.host))
				if not self.connect():
					pprint("SSH re-connect to '{0}' failed".format(self.host))
					return False
			stdin, stdout, stderr = self.exec_command(cmd, timeout=30)
			if res is not None:
				for line in stdout:
					res.append(line)
				for line in stderr:
					res.append(line)
		except Exception as e:
			pprint("Failed to do '{0}' on '{1}' - {2}".format(cmd, self.host, str(e)))
			return False

		return True

	def Execute(self, cmd='', res=None):
		if self.Login():
			stdin, stdout, stderr = self.exec_command(cmd)
			if res is not None:
				for line in stdout:
					res.append(line)
				for line in stderr:
					res.append(line)
			self.close()
			return True
		return False

	def drop_all_checkpoints(self):
		return self.Execute('sudo rm -rf /var/lib/logicube/ckpoints/*')

	def delete_repository_path(self, repo, path):
		r = repo.lower().replace('_', '-')
		return self.Execute('sudo rm -rf /var/repo/{repo}/{path}'.format(repo=r, path=path))

	def get_dest_repo_path(self, repo):
		path='/var/repo/{0}'.format(repo.lower().replace('_', '-'))
		pprint(path)
		return path

	def run_io_to_repo(self, repo):
		res = []
		pprint(repo)
		path = self.get_dest_repo_path(repo)
		assert self.Execute("sudo dd of={0}/testfile.out if=/dev/zero bs=8M count=512 oflag=direct".format(path), res)
		time.sleep(5)
		pprint("[*] result {0}".format(res[2].strip('\n')))

	def refresh_partitions(self, drv):
		res = []
		r = self.Execute("sudo blockdev --rereadpt {0}".format(drv[0]['Path']), res)
		assert r
		pprint(res)
		assert len([s for s in res if "ioctl error" in s]) == 0, [s for s in res if "ioctl error" in s]

	def get_read_only(self, drv):
		res = []
		r = self.Execute("sudo blockdev --getro {0}".format(drv[0]['Path']), res)
		assert r
		pprint(res)
		return res[0].strip("\n")

	def check_read_only(self, drv):
		assert self.get_read_only(drv) == "1"

	def check_read_write(self, drv):
		assert self.get_read_only(drv) == "0"
