*** Settings ***
Documentation     A resource file with reusable keywords for backend test automation.

Resource        variables.robot
Library         Collections
Library         String
# XmlRpcApi <host> <port>
Library         XmlRpcApi	${HOST}	${PORT}
# SecureShell <host> <port> <headless?>
Library         SecureShell	${HOST}

*** Keywords ***
# Set Task Configuration	<task> <config>
# Set Task Configuration	Image:1|...|Push:5 &{cfg}
Set Task Configuration
	[Arguments]	${task}=${VARIABLE}	${cfg}=${VARIABLE}
	${tcfg}=	Convert To Dictionary	${cfg}
	Task Set Config	${task}	${tcfg}

# Set Wipe Format	<task> <fs> <enc>
# Set Wipe Format	Wipe:1|...|Wipe:5 ntfs|ext4|exfat|fat32|ext3|ext2|hfs+	${true}|${false}
Set Wipe Format
	[Arguments]	${task}=${VARIABLE}	${fs}=${VARIABLE}	${enc}=${VARIABLE}
	&{cfg}=	Create Dictionary	WipeFormat=${true}	WipeFilesystem=${fs}	EncryptEnable=${enc}
	Set Task Configuration	${task}	${cfg}

# Set Wipe Method	<task> method  values  lba
# Set Wipe Method	Wipe:1|...|Wipe:5  Custom|DoD  [0xAA, 0x00] 65536
Set Wipe Method
	[Arguments]	${task}=${VARIABLE}	${method}=${VARIABLE}	${lba}=${VARIABLE}
	&{cfg}=	Create Dictionary	WipeMethod=${method}	LBACount=${lba}
	Run Keyword If	'${lba}' == '0'	Pop From Dictionary	${cfg}	LBACount
	Set Task Configuration	${task}	${cfg}

# Set Imaging Config	<task> <mode> <segment size> <comp>
# Set Imaging Config	Image:1|...|Image:5 DriveToE01|DriveToEx01|DriveToDD|DriveToDMG	2Gb|4Gb|8Gb|16Gb|WholeDisk	Default|None
Set Imaging Config
	[Arguments]  ${task}=${VARIABLE}	${mode}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}
	&{cfg}=	Create Dictionary	CloneMode=${mode}	SegmentSize=${segsz}	CompressionLevel=${comp}
	Set Task Configuration	${task}	${cfg}

# Set Clone Config	<task> <method>
# Set Clone Config	Image:1|...|Image:5 Mirror|Clever
Set Clone Config
	[Arguments]  ${task}=${VARIABLE}	${method}=${VARIABLE}	${lba}=${VARIABLE}
	&{cfg}=	Create Dictionary	CloneMode=DriveToDrive	CloneMethod=${method}	LBACount=${lba}
	Run Keyword If	'${lba}' == '0'	Pop From Dictionary	${cfg}	LBACount
	Set Task Configuration	${task}	${cfg}

# Set Restore Config	<task> <source repo> <case name> <verify>
# Set Restore Config	Image:1|...|Image:5 SAS_D2  E01Capture  True|False
Set Restore Config
	[Arguments]  ${task}=${VARIABLE}	${src_repo}=${VARIABLE}	${case_name}=${VARIABLE}	${vrfy}=${VARIABLE}
	${spath}=	Get Dest Repo Path	${src_repo}
	@{clist}=	Create List	${case_name}
	&{pcfg}=	Create Dictionary	CloneMode=ImageToDrive	CloneMethod=FxImage	MountPath=${spath}	CaseList=${clist}	VerifyHash=${vrfy}
	${cfg}=	Convert To Dictionary	${pcfg}
	Set Task Configuration	${task}	${cfg}

# Set Push Config	<task> <source repo> <case name> <verify>
# Set Push Config	Push:1|...|Push:5 SAS_D2  E01Capture  True|False  SATA_D4  pushed_captures
Set Push Config
	[Arguments]  ${task}=${VARIABLE}	${src_repo}=${VARIABLE}	${case_name}=${VARIABLE}	${vrfy}=${VARIABLE}	${dst_repo}=${VARIABLE}	${dst_path}=${VARIABLE}
	${spath}=	Get Dest Repo Path	${src_repo}
	@{clist}=	Create List	${case_name}
	@{cplist}=	Create List	${dst_path}
	&{pcfg}=	Create Dictionary	MountPath=${spath}	CaseList=${clist}	VerifyHash=${vrfy}
	${cfg}=	Convert To Dictionary	${pcfg}
	Set Task Configuration	${task}	${cfg}
	Task Set Repositories	${task}	${dst_repo}	${cplist}

# Start Task	<task>
# Start Task	Image:1|Wipe:3|Hash:1|Push:5
Start Task
	[Arguments]  ${task}=${VARIABLE}
	Task Run	${task}
	Wait Until Keyword Succeeds	15s	3s	Is Task Running	${task}

# Start All Tasks	[tasks]
# Start All Tasks	[Image:1, Wipe:2]
Start All Tasks
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Start Task	${t}
	END

# Confirm Task Successful	<task>
# Confirm Task Successful	Image:1
Confirm Task Successful
	[Arguments]  ${task}=${VARIABLE}
	${status}=	Task status Get	${task}
	Should Be Equal	${status}	TASK_COMPLETED

# Confirm All Tasks Successful	[tasks]
# Confirm All Tasks Successful	['Image:1', 'Wipe:2']
Confirm All Tasks Successful
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Confirm Task Successful	${t}
	END

# Delete All Tasks	[tasks]
# Delete All Tasks	['Image:1', 'Wipe:2']
Delete All Tasks
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Task Delete	${t}
	END

Show All Drives
	@{src}    Get Source Drives
	FOR	${d}	IN	@{src}
		Log	${d}
	END
	@{dst}    Get Destination Drives
	FOR	${d}	IN	@{dst}
		Log	${d}
	END

Show All Bays
	@{src}    Get Source Bays
	FOR	${d}	IN	@{src}
		Log	${d}
	END
	@{dst}    Get Destination Bays
	FOR	${d}	IN	@{dst}
		Log	${d}
	END

Show All Pairs
	&{pairs}    Get All Pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
	END

Show All SAS SATA
	@{BAYS}=	Get All Bays	^SAS_|SATA_
	FOR	${B}	IN	${BAYS}
		Log	${B}
	END

Show One2One Pairs
	&{pairs}    Get Pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
	END
