*** Settings ***
Documentation     Drive-To-Image smoke Test script
Resource          ${LIBRARY}/resource.be.robot

*** Keywords ***
Capture DriveToFile
	[Arguments]	${method}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${hash}=${VARIABLE}	${vrfy}=${VARIABLE}
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
		Run Keyword If	${task} > 1	Task Add	Image:${task}
		Set Imaging Config	Image:${task}	${method}	${segsz}	${comp}
		Task Set Master	Image:${task}	${p}[0]
		Task Set Hash	Image:${task}	${hash}	${vrfy}
		Task Set Repositories	Image:${task}	${p}[1]
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start and monitor all tasks
	Start All Tasks	${tasks}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Delete All Tasks	${tasks}

Wipe Format
	[Arguments]	${task}=${VARIABLE}	${fs}=${VARIABLE}	${enc}=${VARIABLE}
	Task Set Targets	${task}
	Set Wipe Format	${task}	${fs}	${enc}
	Start Task	${task}
	${tasks}=	Create List	${task}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Task Delete	${task}

*** Test Cases ***
TEST_PREP
	Task Delete All	Image
	Task Delete All	Wipe
	Task Delete All	Hash

WIPE_FORMAT_ALL_EXT4
	Wipe Format	Wipe:1	ext4	${false}

TEST_DD_ALL_PAIRS
	Capture DriveToFile	DriveToDD	4Gb	None	SHA-1	Primary

WIPE_FORMAT_ALL_NTFS
	Wipe Format	Wipe:1	ntfs	${false}

TEST_E01_ALL_PAIRS
	Capture DriveToFile	DriveToE01	4Gb	Default	SHA-1	Primary

WIPE_FORMAT_ALL_EXFAT
	Wipe Format	Wipe:1	exfat	${false}

TEST_EX01_ALL_PAIRS
	Capture DriveToFile	DriveToEx01	4Gb	Default	SHA-1	Primary

TEST_PARALLEL_CAPTURE
	@{src}    Get Source Bays
	@{dst}    Get Destination Bays

	# Setup a E01 task to destination 1
	Set Imaging Config	Image:1	DriveToE01	4Gb	Default
	Task Set Master	Image:1	${src}[0]
	Task Set Hash	Image:1	SHA1-MD5	Both
	Task Set Repositories	Image:1	${dst}[0]

	# Setup a DD task to destination 2
	Task Add	Image:2
	Set Imaging Config	Image:2	DriveToDD	4Gb	None
	Task Set Master	Image:2	${src}[0]
	Task Set Hash	Image:2	SHA-1	Primary
	Task Set Repositories	Image:2	${dst}[1]

	# Setup hash with source 1
	Task Set Targets	Hash:1	${src}[0]
	Task Set Hash	Hash:1	SHA-1

	# Start and monitor parallel tasks
	${tasks}=	Create List	Image:1	Image:2	Hash:1
	Start Parallel Tasks	${tasks}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Delete All Tasks	${tasks}
