*** Settings ***
Documentation     FNG-264 smoke Test script
Resource          ${LIBRARY}/resource.be.robot

*** Keywords ***

*** Test Cases ***
TEST_PREP
	Task Delete All	Image
	Task Delete All	Hash
	Task Delete All	Wipe

MIRROR_CLONE
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Run Keyword If	${task} > 1	Task Add	Image:${task}
		Set Clone Config	Image:${task}	Mirror	0
		Task Set Master	Image:${task}	${p}[0]
		Task Set Hash	Image:${task}	SHA-1	${true}
		Task Set Targets	Image:${task}	${p}[1]
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start and monitor all tasks
	Start All Tasks	${tasks}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Delete All Tasks	${tasks}

	FOR	${p}	IN	&{pairs}
		Log	${p}
		${src_npart}=	Get Bay Num Parts	${p}[0]
		${dst_npart}=	Get Bay Num Parts	${p}[1][0]
		Should Be Equal	${src_npart}	${dst_npart}
	END

WIPE_DST
	Task Set Targets	Wipe:1
	@{values}=	Create List	0xAA
	@{vrfy}=	Create List	${0}
	Set Wipe Method	Wipe:1	Custom	65536
	Set Wipe Values	Wipe:1	${values}	${vrfy}
	Start Task	Wipe:1
	${tasks}=	Create List	Wipe:1
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Task Delete	Wipe:1

	# Make sure the number of partitions match
	@{dst}    Get Destination Bays
	FOR	${d}	IN	@{dst}
		${npart}=	Get Bay Num Parts	${d}
		Should Be Equal	${npart}	${0}
	END

TEST_PARTITION_REREAD
	@{drv}    Get Destination Drives
	FOR	${d}	IN	@{drv}
		Refresh Partitions	${d}
	END

WIPE_FORMAT
	Task Set Targets	Wipe:1
	Set Wipe Format	Wipe:1	ntfs	${false}
	Start Task	Wipe:1
	${tasks}=	Create List	Wipe:1
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Task Delete	Wipe:1

	# Make sure the number of partitions match
	@{dst}    Get Destination Bays
	FOR	${d}	IN	@{dst}
		${npart}=	Get Bay Num Parts	${d}
		Should Be Equal	${npart}	${1}
	END
