*** Settings ***
Documentation     NAS repository capture, push and restore smoke Test script
Resource          ${LIBRARY}/resource.be.robot

*** Variables ***
${ID}	NONE
&{NAS_REPO1}	Name=nas_repo_test1	Path=192.168.1.23/upload	Username=logicube	Password=logicube	Location=Network	Role=Both
&{NAS_REPO2}	Name=nas_repo_test2	Path=192.168.1.24/upload	Username=logicube	Password=logicube	Location=Network	Role=Both
@{NAS_REPOS}	&{NAS_REPO1}	&{NAS_REPO2}

*** Keywords ***
Setup Nas Repos
	${id}	Get Unit Identifier
	Set Global Variable	${ID}	${id}
	FOR	${r}	IN	@{NAS_REPOS}
		Log	${r}
		${exists}=	Is Network Repo Mounted	${r}[Name]	${r}[Path]
		Run Keyword If	${exists}	Remove Network Repo	${r}[Name]	${r}[Path]
		${cfg}=	Convert To Dictionary	${r}
		Add Network Repo	${cfg}
		Create Repo Dir	${r}[Name]	nas_test_${id}
	END

Run Task
	[Arguments]	${task}=${VARIABLE}
	${tasks}=	Create List	${task}
	Start All Tasks	${tasks}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Delete All Tasks	${tasks}

Capture DriveToFile
	[Arguments]	${name}=${VARIABLE}	${method}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${hash}=${VARIABLE}	${vrfy}=${VARIABLE}
	@{src}    Get Source Bays
	
	Set Imaging Config	Image:1	${method}	${segsz}	${comp}
	Task Set Case Name	Image:1	${name}
	Task Set Master	Image:1	${src}[0]
	Task Set Hash	Image:1	${hash}	${vrfy}
	@{path}=	Create List	nas_test_${ID}
	Task Set Repositories	Image:1	nas_repo_test1	${path}
	Run Task	Image:1

Run FileToDrive
	[Arguments]	${name}=${VARIABLE}
	@{src}    Get Source Bays
	@{dst}    Get Destination Bays
	
	Task Add	Image:2
	Set Restore Config	Image:2	nas_repo_test1	nas_test_${ID}/${name}	${true}
	Task Set Targets	Image:2	${dst}[0]
	Run Task	Image:2

Run Push
	[Arguments]	${name}=${VARIABLE}
	Set Push Config	Push:1	nas_repo_test1	nas_test_${ID}/${name}	${true}	nas_repo_test2	nas_test_${ID}
	Run Task	Push:1

*** Test Cases ***
TEST_PREP
	Task Delete All	Image
	Task Delete All	Hash
	Task Delete All	Push
	Setup Nas Repos

TEST_E01
	Capture DriveToFile	E01Test	DriveToE01	4Gb	Default	SHA-1	Primary
	Run Push	E01Test
	Run FileToDrive	E01Test

TEST_EX01
	Capture DriveToFile	Ex01Test	DriveToEX01	4Gb	Default	SHA-1	Primary
	Run Push	Ex01Test
	Run FileToDrive	Ex01Test

TEST_DD
	Capture DriveToFile	DDTest	DriveToDD	4Gb	Default	SHA-1	Primary
	Run Push	DDTest
	Run FileToDrive	DDTest

TEST_CLEANUP
	FOR	${r}	IN	@{NAS_REPOS}
		Delete Repository Path	${r}[Name]	nas_test_${ID}/
	END

