*** Settings ***
Documentation     NAS iSCSI targets smoke Test script
Resource          ${LIBRARY}/resource.be.robot

*** Variables ***
${ID}	NONE
&{NAS_ISCSI}	Portal=192.168.1.23	User=	Passwd=	Role=Both

*** Keywords ***
Setup iSCSI
	${id}	Get Unit Identifier
	Set Global Variable	${ID}	${id}
	# Disconnect from iSCSI portal if connected
	Disconnect Iscsi Portal	${NAS_ISCSI}[Portal]
	# Connect to iSCSI portal
	Connect Iscsi Portal	${NAS_ISCSI}[Portal]	${NAS_ISCSI}[User]	${NAS_ISCSI}[Passwd]	${NAS_ISCSI}[Role]
	Sleep	10s

Run Task
	[Arguments]	${task}=${VARIABLE}
	${tasks}=	Create List	${task}
	Start All Tasks	${tasks}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Delete All Tasks	${tasks}

Capture DriveToFile
	[Arguments]	${name}=${VARIABLE}	${method}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${hash}=${VARIABLE}	${vrfy}=${VARIABLE}
	@{src}    Get Source Bays
	@{repos}=	Get Iscsi Repo List

	${nrepos}=	Get Length	${repos}
	Should Be True	${nrepos} > 0
	Set Imaging Config	Image:1	${method}	${segsz}	${comp}
	Task Set Case Name	Image:1	${name}
	Task Set Master	Image:1	${src}[0]
	Task Set Hash	Image:1	${hash}	${vrfy}
	Task Set Repositories	Image:1	${repos}
	Run Task	Image:1

*** Test Cases ***
TEST_PREP
	Task Delete All	Image
	Task Delete All	Wipe
	Setup iSCSI

TEST_DRIVE_2_DRIVE
	@{src}=	Get Source Bays
	@{dst}=	Get Iscsi Bay List

	${ndst}=	Get Length	${dst}
	Should Be True	${ndst} > 0
	Set Clone Config	Image:1	Mirror	65536
	Task Set Master	Image:1	${src}[0]
	Task Set Hash	Image:1	SHA-1	${true}
	Task Set Targets	Image:1	${dst}
	Run Task	Image:1

TEST_WIPE_FORMAT
	@{dst}=	Get Iscsi Bay List
	${ndst}=	Get Length	${dst}
	Should Be True	${ndst} > 0
	Task Set Targets	Wipe:1	${dst}
	Set Wipe Format	Wipe:1	ntfs	${false}
	Run Task	Wipe:1

TEST_E01
	Capture DriveToFile	E01Test	DriveToE01	4Gb	Default	SHA1-MD5	Both

TEST_EX01
	Capture DriveToFile	Ex01Test	DriveToEx01	4Gb	Default	SHA-1	Primary

TEST_DD
	Capture DriveToFile	DDTest	DriveToDD	4Gb	Default	SHA-1	Primary

TEST_CLEANUP
	Disconnect Iscsi Portal	${NAS_ISCSI}[Portal]
