*** Settings ***
Documentation     Forensic performance benchmarking script. This script is
...               supposed be run with 256GB Samsung EVO 840 Pro SSDs
...               connected to SAS_S1 & SAS_S2 and 4 1TB Samsung 860 EVO
...               SSDs connected to SAS/SATA destinations. Additionally
...               2 high speed PCIe drives should be connected to source
...               and destination ports.
Resource          ${LIBRARY}/resource.be.robot

*** Keywords ***
Run Tasks
	[Arguments]	${tasks}=${VARIABLE}
	Start All Tasks	${tasks}
	Wait For Task Completion	${tasks}	${true}
	Confirm All Tasks Successful	${tasks}
	Delete All Tasks	${tasks}

Setup DriveToFile
	[Arguments]	${task}=${VARIABLE}	${method}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${hash}=${VARIABLE}	${vrfy}=${VARIABLE}	${src}=${VARIABLE}	${dst}=${VARIABLE}
	Run Keyword If	${task} > 1	Task Add	Image:${task}
	Set Imaging Config	Image:${task}	${method}	${segsz}	${comp}
	Task Set Master	Image:${task}	${src}
	Task Set Hash	Image:${task}	${hash}	${vrfy}
	Task Set Repositories	Image:${task}	${dst}

Wipe Format
	[Arguments]	${task}=${VARIABLE}	${fs}=${VARIABLE}	${enc}=${VARIABLE}	${dst}=${VARIABLE}
	Task Set Targets	${task}	${dst}
	Set Wipe Format	${task}	${fs}	${enc}
	Start Task	${task}
	${tasks}=	Create List	${task}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Task Delete	${task}

Run Single Test
	[Arguments]	${test}=${VARIABLE}	${src}=${VARIABLE}	${dst}=${VARIABLE}
	@{tasks}=	Create List	Image:1

	Wipe Format	Wipe:1	ntfs	${false}	${dst}
	Log Perf Info	Benchmarking ${test} SHA-1
	Setup DriveToFile	1	DriveToE01	4Gb	Default	SHA-1	Primary	${src}	${dst}
	Run Tasks	${tasks}

	Log Perf Info	Benchmarking ${test} SHA1-MD5
	Setup DriveToFile	1	DriveToE01	4Gb	Default	SHA1-MD5	Both	${src}	${dst}
	Run Tasks	${tasks}

	Log Perf Info	Benchmarking ${test} MD5
	Setup DriveToFile	1	DriveToE01	4Gb	Default	MD5	Primary	${src}	${dst}
	Run Tasks	${tasks}

Run Multi Test
	[Arguments]	${test}=${VARIABLE}	${src1}=${VARIABLE}	${dst1}=${VARIABLE}	${src2}=${VARIABLE}	${dst2}=${VARIABLE}
	@{tasks}=	Create List	Image:1	Image:2

	Wipe Format	Wipe:1	ntfs	${false}	^SAS_D|SATA_D
	Log Perf Info	Benchmarking ${test} SHA-1
	Setup DriveToFile	1	DriveToE01	4Gb	Default	SHA-1	Primary	${src1}	${dst1}
	Setup DriveToFile	2	DriveToE01	4Gb	Default	SHA-1	Primary	${src2}	${dst2}
	Run Tasks	${tasks}

	Log Perf Info	Benchmarking ${test} SHA1-MD5
	Setup DriveToFile	1	DriveToE01	4Gb	Default	SHA1-MD5	Both	${src1}	${dst1}
	Setup DriveToFile	2	DriveToE01	4Gb	Default	SHA1-MD5	Both	${src2}	${dst2}
	Run Tasks	${tasks}

	Log Perf Info	Benchmarking ${test} MD5
	Setup DriveToFile	1	DriveToE01	4Gb	Default	MD5	Primary	${src1}	${dst1}
	Setup DriveToFile	2	DriveToE01	4Gb	Default	MD5	Primary	${src2}	${dst2}
	Run Tasks	${tasks}

*** Test Cases ***
TEST_PREP
	Task Delete All	Image
	Task Delete All	Wipe
	Task Delete All	Hash
	Enable Perf Log

TEST_E01_1TO1
	Run Single Test	1-To-1 E01	^SAS_S1	^SATA_D3

TEST_E01_1TO2
	Run Single Test	1-To-2 E01	^SAS_S1	^SATA_D

TEST_E01_1TO3
	Run Single Test	1-To-3 E01	^SAS_S1	^SAS_D1|SATA_D

TEST_E01_1TO4
	Run Single Test	1-To-4 E01	^SAS_S1	^SAS_D|SATA_D

TEST_E01_2TO1
	Run Multi Test	2-To-1 E01	^SAS_S1	^SATA_D3	^SAS_S2	^SATA_D4

TEST_E01_2TO2
	Run Multi Test	2-To-2 E01	^SAS_S1	^SAS_D1|SATA_D3	^SAS_S2	^SAS_D2|SATA_D4

TEST_PCIE_D2D
	@{tasks}=	Create List	Image:1
	@{src}=	Get Source Bays	^PCIe
	@{dst}=	Get Destination Bays	^PCIe

	${ndst}=	Get Length	${dst}
	${nsrc}=	Get Length	${src}
	Should Be True	${ndst} > 0 and ${nsrc} > 0
	Set Clone Config	Image:1	Mirror	0
	Task Set Master	Image:1	${src}[0]
	Task Set Hash	Image:1	NONE	${false}
	Task Set Targets	Image:1	${dst}
	Run Tasks	${tasks}
