*** Settings ***
Documentation     DriveToFile Capture with case verify
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Capture Screen On Failure
Suite Teardown    Close Ui

*** Comments ***
# Following Variables can be overridden via commandline arguments
# hash: Hash method - use HASH:<hash type>. Where hash type can be None, SHA1, SHA256, MD5, SHA1MD5, SHA1SHA256, MD5SHA256
# vrify: Verify method - use VRFY:<type>. Where type can be NONE, PRIMARY, BOTH
# format: Destination Filesystem format - use FRMT:<filesystem>. Where filesystem can be NTFS, EXT4, EXFAT, FAT, EXT2, EXT3, HFSP
# source: use CSRC:<pattern/port name>. for e.g. CSRC:^SAS_S for any SAS drive or CSRC:SAS_S1
# dest: use DEST:<pattern/port name>. for e.g. DEST:^SAS_D for any SAS drive or DEST:SAS_D1; use DEST:NAS to setup and use NAS destination
# For e.g ./run_test -h 192.168.5.49 -t testcases/falcon-neo/ui/d2f-nas.robot -v HASH:SHA1MD5 -v VRFY:BOTH -v DEST:SAS_D2 -v FRMT:EXFAT

*** Variables ***
${HASH}	SHA1
${VRFY}	PRIMARY
${FRMT}	NTFS
${UNIT}	test-unit
${CSRC}	NONE
${DEST}	NAS

${NAS_PATH}	192.168.1.23/upload
${NAS_USER}	logicube
${NAS_PSWD}	logicube

*** Keywords ***
Set Host Identification
	${id}	Get Unit Identifier
	Set Global Variable	${UNIT}	${id}

Set Source
	@{src}	Get Source Bays
	Set Global Variable	${CSRC}	${src}[0]

Setup NAS Push Destination
	Delete Network Repository	nas
	Add Network Repository	nas	${NAS_PATH}	WORKGROUP	${NAS_USER}	${NAS_PSWD}	Both	Any
	Set Global Variable	${DEST}	nas
	Delete Repository Path	nas	${UNIT}

Capture DriveToFile
	[Arguments]	${method}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${path}=${VARIABLE}
	Setup DriveToFile	1	${method}	${CSRC}	${name}	${segsz}	${comp}	${HASH}	${VRFY}	${DEST}	${path}
	Start Task	Image:1
	Wait For Task	Image:1
	Confirm Task Successful	Image:1
	Delete Task	Image:1

Setup CaseVerify
	[Arguments]	${task}=${VARIABLE}	${dst}=${VARIABLE}	${path}=${VARIABLE}
	Run Keyword If	${task} > 1	Add Tasks	Hash	1
	Go To Task	Hash:${task}
	Set Hash Task Mode	CaseVerify
	Select Case	Hash	Target	${dst}	${path}
	Set Case Verify Mode	${VRFY}

Verify DriveToFile
	[Arguments]	${path}=${VARIABLE}
	Setup CaseVerify	1	${DEST}	${path}
	Start Task	Hash:1
	Wait For Task	Hash:1
	Confirm Task Successful	Hash:1
	Delete Task	Hash:1

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Delete All Tasks	Image
	Delete All Tasks	Hash
	Delete All Tasks	Wipe
	Run Keyword If	'${UNIT}' == 'test-unit'	Set Host Identification
	Drop All Checkpoints
	Run Keyword If	'${CSRC}' == 'NONE'	Set Source
	Setup NAS Push Destination

IMAGE_D2F_EX01
	Delete Repository Path	nas	${UNIT}
	Capture DriveToFile	EX01	2gb_cap	2GB	${false}	ex01_cap_test
	Capture DriveToFile	EX01	4gb_cap	4GB	${true}	ex01_cap_test
	Capture DriveToFile	EX01	8gb_cap	8GB	${true}	ex01_cap_test
	Capture DriveToFile	EX01	16gb_cap	16GB	${true}	ex01_cap_test
	Verify DriveToFile	ex01_cap_test

IMAGE_D2F_E01
	Delete Repository Path	nas	${UNIT}
	Capture DriveToFile	E01	2gb_cap	2GB	${false}	e01_cap_test
	Capture DriveToFile	E01	4gb_cap	4GB	${true}	e01_cap_test
	Capture DriveToFile	E01	8gb_cap	8GB	${true}	e01_cap_test
	Capture DriveToFile	E01	16gb_cap	16GB	${true}	e01_cap_test
	Verify DriveToFile	e01_cap_test

IMAGE_D2F_DD_DMG
	Delete Repository Path	nas	${UNIT}
	Capture DriveToFile	DD	2gb_cap	2GB	${false}	ddmg_cap_test
	Capture DriveToFile	DMG	4gb_cap	4GB	${false}	ddmg_cap_test
	Capture DriveToFile	DD	8gb_cap	8GB	${false}	ddmg_cap_test
	Capture DriveToFile	DMG	16gb_cap	16GB	${false}	ddmg_cap_test
	Verify DriveToFile	ddmg_cap_test
