*** Settings ***
Documentation     DriveToFile Capture with case verify
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Capture Screen On Failure
Suite Teardown    Close Ui

*** Comments ***
# Following Variables can be overridden via commandline arguments
# hash: Hash method - use HASH:<hash type>. Where hash type can be None, SHA1, SHA256, MD5, SHA1MD5, SHA1SHA256, MD5SHA256
# vrify: Verify method - use VRFY:<type>. Where type can be NONE, PRIMARY, BOTH
# format: Destination Filesystem format - use FRMT:<filesystem>. Where filesystem can be NTFS, EXT4, EXFAT, FAT, EXT2, EXT3, HFSP
# For e.g ./run_test -h 192.168.5.49 -t testcases/falcon-neo/ui/drive-2-file.robot -v HASH:SHA1MD5 -v VRFY:BOTH -v FRMT:EXFAT

*** Variables ***
${HASH}	SHA1
${VRFY}	PRIMARY
${FRMT}	NTFS

*** Keywords ***
Capture DriveToFile
	[Arguments]	${method}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${path}=${VARIABLE}
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Setup DriveToFile	${task}	${method}	${p}[0]	${name}	${segsz}	${comp}	${HASH}	${VRFY}	${p}[1]	${path}
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}
	# Wait for all tasks to end
	Wait For Tasks	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}
	Delete Tasks	${tasks}

Setup CaseVerify
	[Arguments]	${task}=${VARIABLE}	${dst}=${VARIABLE}	${path}=${VARIABLE}
	Run Keyword If	${task} > 1	Add Tasks	Hash	1
	Go To Task	Hash:${task}
	Set Hash Task Mode	CaseVerify
	Select Case	Hash	Target	${dst}	${path}
	Set Case Verify Mode	${VRFY}

Verify DriveToFile
	[Arguments]	${path}=${VARIABLE}
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Setup CaseVerify	${task}	${p}[1]	${path}
		Append To List	${tasks}	Hash:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}
	# Wait for all tasks to end
	Wait For Tasks	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}
	Delete Tasks	${tasks}

Wipe Format All
	[Tags]    no_tag
	Add Tasks	Wipe	1
	Go To Task	Wipe:2
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	${FRMT}	False
	Start Task	Wipe:2
	Wait For Task	Wipe:2
	Confirm Task Successful	Wipe:2
	Delete Task	Wipe:2

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Delete All Tasks	Image
	Delete All Tasks	Hash
	Delete All Tasks	Wipe

IMAGE_D2F_EX01
	Wipe Format All
	Capture DriveToFile	EX01	2gb_cap	2GB	${false}	ex01_cap_test
	Capture DriveToFile	EX01	4gb_cap	4GB	${true}	ex01_cap_test
	Capture DriveToFile	EX01	8gb_cap	8GB	${true}	ex01_cap_test
	Capture DriveToFile	EX01	16gb_cap	16GB	${true}	ex01_cap_test
	Verify DriveToFile	ex01_cap_test

IMAGE_D2F_E01
	Wipe Format All
	Capture DriveToFile	E01	2gb_cap	2GB	${false}	e01_cap_test
	Capture DriveToFile	E01	4gb_cap	4GB	${true}	e01_cap_test
	Capture DriveToFile	E01	8gb_cap	8GB	${true}	e01_cap_test
	Capture DriveToFile	E01	16gb_cap	16GB	${true}	e01_cap_test
	Verify DriveToFile	e01_cap_test

IMAGE_D2F_DD_DMG
	Wipe Format All
	Capture DriveToFile	DD	2gb_cap	2GB	${false}	ddmg_cap_test
	Capture DriveToFile	DMG	4gb_cap	4GB	${false}	ddmg_cap_test
	Capture DriveToFile	DD	8gb_cap	8GB	${false}	ddmg_cap_test
	Capture DriveToFile	DMG	16gb_cap	16GB	${false}	ddmg_cap_test
	Verify DriveToFile	ddmg_cap_test
