*** Settings ***
Documentation     FileToFile Capture tests
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Capture Screen On Failure
Suite Teardown    Close Ui

*** Comments ***
# Following Variables can be overridden via commandline arguments
# hash: Hash method - use HASH:<hash type>. Where hash type can be None, SHA1, SHA256, MD5, SHA1MD5, SHA1SHA256, MD5SHA256
# format: Destination Filesystem format - use FRMT:<filesystem>. Where filesystem can be NTFS, EXT4, EXFAT, FAT, EXT2, EXT3, HFSP
# source: use CSRC:<pattern/port name>. for e.g. CSRC:^SAS_S for any SAS drive or CSRC:SAS_S1
# dest: use DEST:<pattern/port name>. for e.g. DEST:^SAS_D for any SAS drive or DEST:SAS_D1; use DEST:NAS to setup and use NAS destination
# source dirs: use DIR<n>:<path>. for e.g. DIR1:partn-2_NTFS/Users. DIR1, DIR2 and/or DIR3 can be used.
# For e.g ./run_test -h 192.168.5.49 -t testcases/falcon-neo/ui/file-2-file.robot -v HASH:SHA1 -v DEST:SAS_D2 -v FRMT:EXFAT

*** Variables ***
${HASH}	SHA1
${FRMT}	NTFS
${UNIT}	test-unit
${CSRC}	NONE
${DIR1}	partn-2_FAT32/EFI/Microsoft/Recovery
${DIR2}	partn-2_FAT32/System Volume Information/ClientRecoveryPasswordRotation
${DIR3}	NONE
${DEST}	NONE

${NAS_PATH}	192.168.1.23/upload
${NAS_USER}	logicube
${NAS_PSWD}	logicube

*** Keywords ***
Set Host Identification
	${id}	Get Unit Identifier
	Set Global Variable	${UNIT}	${id}

Set Source
	@{src}	Get Source Bays
	Set Global Variable	${CSRC}	${src}[0]

Setup NAS Push Destination
	Delete Network Repository	nas
	Add Network Repository	nas	${NAS_PATH}	WORKGROUP	${NAS_USER}	${NAS_PSWD}	Both	Any
	Set Global Variable	${DEST}	nas
	Delete Repository Path	nas	${UNIT}

Capture FileToFile
	[Arguments]	${mode}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${dst}=${VARIABLE}	${path}=${VARIABLE}
	@{dirs}=	Create List
	Run Keyword If	'${DIR1}' != 'NONE'	Append To List	${dirs}	${DIR1}
	Run Keyword If	'${DIR2}' != 'NONE'	Append To List	${dirs}	${DIR2}
	Run Keyword If	'${DIR3}' != 'NONE'	Append To List	${dirs}	${DIR3}
	Setup FileToFile	1	${mode}	${CSRC}	${name}	${dirs}	${segsz}	${comp}	${HASH}	${true}	${DEST}	${path}
	Start Task	Image:1
	Wait For Task	Image:1
	Confirm Task Successful	Image:1
	Delete Task	Image:1

Wipe Format All
	[Tags]    no_tag
	Add Tasks	Wipe	1
	Go To Task	Wipe:2
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	${FRMT}	False
	Start Task	Wipe:2
	Wait For Task	Wipe:2
	Confirm Task Successful	Wipe:2
	Delete Task	Wipe:2

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Delete All Tasks	Image
	Delete All Tasks	Wipe
	Run Keyword If	'${UNIT}' == 'test-unit'	Set Host Identification
	Run Keyword If	'${CSRC}' == 'NONE'	Set Source
	@{dst}    Get Destination Bays
	${ndst}=	Get Length	${dst}
	Run Keyword If	'${DEST}' == 'NAS'	Setup NAS Push Destination
	Run Keyword If	'${DEST}' == 'NONE' and ${ndst} > 0	Set Global Variable	${DEST}	${dst}[0]

IMAGE_F2F_L01
	Wipe Format All
	Capture FileToFile	L01	2gb_cap	2GB	${true}	${DEST}	${UNIT}/l01_test
	Capture FileToFile	L01	4gb_cap	4GB	${true}	${DEST}	${UNIT}/l01_test
	Capture FileToFile	L01	8gb_cap	8GB	${true}	${DEST}	${UNIT}/l01_test
	Capture FileToFile	L01	16gb_cap	16GB	${true}	${DEST}	${UNIT}/l01_test

IMAGE_F2F_LX01
	Wipe Format All
	Capture FileToFile	LX01	2gb_cap	2GB	${true}	${DEST}	${UNIT}/lx01_test
	Capture FileToFile	LX01	4gb_cap	4GB	${true}	${DEST}	${UNIT}/lx01_test
	Capture FileToFile	LX01	8gb_cap	8GB	${true}	${DEST}	${UNIT}/lx01_test
	Capture FileToFile	LX01	16gb_cap	16GB	${true}	${DEST}	${UNIT}/lx01_test

IMAGE_F2F_OTH
	Wipe Format All
	Capture FileToFile	DIR	dir_cap	NONE	${false}	${DEST}	${UNIT}/f2f_test
	Capture FileToFile	ZIP	zip_cap	NONE	${false}	${DEST}	${UNIT}/f2f_test
