*** Settings ***
Documentation     Tests for validating parallel operation tasks for single source.
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Capture Screen On Failure
Suite Teardown    Close Ui

*** Comments ***
# Following Variables can be overridden via commandline arguments
# hash: Hash method - use HASH:<hash type>. Where hash type can be None, SHA1, SHA256, MD5, SHA1MD5, SHA1SHA256, MD5SHA256
# vrify: Verify method - use VRFY:<type>. Where type can be NONE, PRIMARY, BOTH
# format: Destination Filesystem format - use FRMT:<filesystem>. Where filesystem can be NTFS, EXT4, EXFAT, FAT, EXT2, EXT3, HFSP
# source: use CSRC:<pattern/port name>. for e.g. CSRC:^SAS_S for any SAS drive or CSRC:SAS_S1
# dest1: use DEST1:<pattern/port name>. for e.g. DEST1:^SAS_D for any SAS drive or DEST1:SAS_D1; use DEST1:NAS to setup and use NAS destination
# dest2: use DEST2:<pattern/port name>. for e.g. DEST2:^SAS_D for any SAS drive or DEST2:SAS_D1; use DEST2:NAS to setup and use NAS destination
# For e.g ./run_test -h 192.168.5.49 -t testcases/falcon-neo/ui/parallel-tasks.robot -v HASH:SHA1MD5 -v VRFY:BOTH -v DEST:SAS_D2 -v FRMT:EXFAT

*** Variables ***
${HASH}	SHA1
${VRFY}	PRIMARY
${FRMT}	NTFS
${DST1}	NONE
${DST2}	NONE
${UNIT}	test-unit

${NAS_PATH}	192.168.1.23/upload
${NAS_USER}	logicube
${NAS_PSWD}	logicube

*** Keywords ***
Set Host Identification
	${id}	Get Unit Identifier
	Set Global Variable	${UNIT}	${id}

Setup NAS Destnation
	Delete Network Repository	nas
	Add Network Repository	nas	${NAS_PATH}	WORKGROUP	${NAS_USER}	${NAS_PSWD}	Both	Any
	Set Global Variable	${DST2}	nas

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Run Keyword If	'${UNIT}' == 'test-unit'	Set Host Identification
	Delete All Tasks	Image
	Delete All Tasks	Hash
	Delete All Tasks	Wipe
	Drop All Checkpoints
	@{dst}    Get Destination Bays
	${ndst}=	Get Length	${dst}
	Log	${ndst}
	Run Keyword If	'${DST1}' == 'NONE' and ${ndst} > 0	Set Global Variable	${DST1}	${dst}[0]
	Run Keyword If	'${DST2}' == 'NAS'	Setup NAS Destnation
	Run Keyword If	'${DST2}' == 'NONE' and ${ndst} > 1	Set Global Variable	${DST2}	${dst}[1]
	# If push destination is still NONE,
	Run Keyword If	'${DST2}' == 'NONE'	Setup NAS Destnation
	Log	${DST1}
	Log	${DST2}

WIPE_FORMAT_DST
	[Tags]    no_tag
	Go To Task	Wipe:1
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	${FRMT}	False
	Start Task	Wipe:1
	Wait For Task	Wipe:1
	Confirm Task Successful	Wipe:1

IMAGE_CAPTURE_E01_EX01
	@{srcs}    Get Source Bays
	FOR	${src}	IN	@{srcs}
		Setup DriveToFile	1	E01	${src}	4gb_e01	4GB	${true}	${HASH}	${VRFY}	${DST1}	${UNIT}/parll_e01_ex01_test
		Setup DriveToFile	2	EX01	${src}	4gb_ex01	4GB	${true}	${HASH}	${VRFY}	${DST2}	${UNIT}/parll_e01_ex01_test
		@{tasks}=	Create List	Image:1	Image:2
		Start Parallel Tasks	${tasks}
		# Wait for all tasks to end
		Wait For Tasks	${tasks}
		# Confirm all tasks successful
		Confirm All Tasks Successful	${tasks}
		Delete Tasks	${tasks}
	END

IMAGE_CAPTURE_EX01_DD_HASH
	@{srcs}    Get Source Bays
	FOR	${src}	IN	@{srcs}
		Setup DriveToFile	1	EX01	${src}	4gb_ex01	4GB	${true}	${HASH}	${VRFY}	${DST1}	${UNIT}/parll_ex01_dd_test
		Setup DriveToFile	2	DD	${src}	4gb_dd	4GB	${true}	${HASH}	${VRFY}	${DST2}	${UNIT}/parll_ex01_dd_test
		Setup HashTask	1	${src}	MD5
		@{tasks}=	Create List	Image:1	Image:2	Hash:1
		Start Parallel Tasks	${tasks}
		# Wait for all tasks to end
		Wait For Tasks	${tasks}
		# Confirm all tasks successful
		Confirm All Tasks Successful	${tasks}
		Delete Tasks	${tasks}
	END

IMAGE_CAPTURE_D2D_E01_HASH
	@{srcs}    Get Source Bays
	FOR	${src}	IN	@{srcs}
		Setup DriveToDrive	1	${src}	d2d	SHA256	${true}	${DST1}
		Setup DriveToFile	2	E01	${src}	4gb_e01	4GB	${true}	${HASH}	${VRFY}	${DST2}	${UNIT}/parll_d2d_e01_test
		Setup HashTask	1	${src}	MD5
		@{tasks}=	Create List	Image:1	Image:2	Hash:1
		Start Parallel Tasks	${tasks}
		# Wait for all tasks to end
		Wait For Tasks	${tasks}
		# Confirm all tasks successful
		Confirm All Tasks Successful	${tasks}
		Delete Tasks	${tasks}
	END
