*** Settings ***
Documentation     Tests for validating push task for Drive To File captures
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Capture Screen On Failure
Suite Teardown    Close Ui

*** Comments ***
# Following Variables can be overridden via commandline arguments
# hash: Hash method - use HASH:<hash type>. Where hash type can be None, SHA1, SHA256, MD5, SHA1MD5, SHA1SHA256, MD5SHA256
# vrify: Verify method - use VRFY:<type>. Where type can be NONE, PRIMARY, BOTH
# format: Destination Filesystem format - use FRMT:<filesystem>. Where filesystem can be NTFS, EXT4, EXFAT, FAT, EXT2, EXT3, HFSP
# source: use CSRC:<pattern/port name>. for e.g. CSRC:^SAS_S for any SAS drive or CSRC:SAS_S1
# capture destination: use CDST:<pattern/port name>. for e.g. CDST:^SAS_D for any SAS drive or CDST:SAS_D1; use CDST:NAS to setup and use NAS destination
# push destination: use PDST:<pattern/port name>. for e.g. PDST:^SAS_D for any SAS drive or PDST:SAS_D1; use PDST:NAS to setup and use NAS destination
# For e.g ./run_test -h 192.168.5.49 -t testcases/falcon-neo/ui/push-d2f.robot -v HASH:SHA1MD5 -v VRFY:BOTH -v PDST:SAS_D2 -v FRMT:EXFAT

*** Variables ***
${HASH}	SHA1
${VRFY}	PRIMARY
${FRMT}	NTFS
${CSRC}	NONE
${CDST}	NONE
${PDST}	NONE
${UNIT}	test-unit

${NAS_PATH}	192.168.1.23/upload
${NAS_USER}	logicube
${NAS_PSWD}	logicube

*** Keywords ***
Set Host Identification
	${id}	Get Unit Identifier
	Set Global Variable	${UNIT}	${id}

Set Source
	@{src}	Get Source Bays
	Set Global Variable	${CSRC}	${src}[0]

Setup NAS Push Destination
	Delete Network Repository	nas
	Add Network Repository	nas	${NAS_PATH}	WORKGROUP	${NAS_USER}	${NAS_PSWD}	Both	Any
	Set Global Variable	${PDST}	nas
	Delete Repository Path	nas	${UNIT}

Capture DriveToFile
	[Arguments]	${method}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${path}=${VARIABLE}
	Setup DriveToFile	1	${method}	${CSRC}	${name}	${segsz}	${comp}	${HASH}	${VRFY}	${CDST}	${path}
	Start Task	Image:1
	Wait For Task	Image:1
	Confirm Task Successful	Image:1
	Delete Task	Image:1

Push Capture
	[Arguments]	${src}=${VARIABLE}	${src_path}=${VARIABLE}	${dst}=${VARIABLE}	${dst_path}=${VARIABLE}
	Setup PushTask	1	${src}	${src_path}	${dst}	${dst_path}
	Start Task	Push:1
	Wait For Task	Push:1
	Confirm Task Successful	Push:1
	Delete Task	Push:1

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Run Keyword If	'${UNIT}' == 'test-unit'	Set Host Identification
	Delete All Tasks	Image
	Delete All Tasks	Wipe
	Delete All Tasks	Push
	Drop All Checkpoints
	Run Keyword If	'${CSRC}' == 'NONE'	Set Source
	@{dst}    Get Destination Bays
	${ndst}=	Get Length	${dst}
	Log	${ndst}
	Run Keyword If	'${CDST}' == 'NONE' and ${ndst} > 0	Set Global Variable	${CDST}	${dst}[0]
	Run Keyword If	'${PDST}' == 'NAS'	Setup NAS Push Destination
	Run Keyword If	'${PDST}' == 'NONE' and ${ndst} > 1	Set Global Variable	${PDST}	${dst}[1]
	# If push destination is still NONE,
	Run Keyword If	'${PDST}' == 'NONE'	Setup NAS Push Destination
	Log	${CSRC}
	Log	${CDST}
	Log	${PDST}

WIPE_FORMAT_DST
	[Tags]    no_tag
	Go To Task	Wipe:1
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	${FRMT}	False
	Start Task	Wipe:1
	Wait For Task	Wipe:1
	Confirm Task Successful	Wipe:1

IMAGE_CAPTURE_E01
	Capture DriveToFile	E01	2gb	2GB	${false}	${UNIT}/e01_test
	Capture DriveToFile	E01	4gb	4GB	${true}	${UNIT}/e01_test
	Capture DriveToFile	E01	8gb	8GB	${false}	${UNIT}/e01_test
	Capture DriveToFile	E01	16gb	16GB	${true}	${UNIT}/e01_test
	Push Capture  ${CDST}	${UNIT}/e01_test	${PDST}	${UNIT}/e01_push_test

IMAGE_CAPTURE_EX01
	Capture DriveToFile	EX01	2gb	2GB	${false}	${UNIT}/ex01_test
	Capture DriveToFile	EX01	4gb	4GB	${true}	${UNIT}/ex01_test
	Capture DriveToFile	EX01	8gb	8GB	${false}	${UNIT}/ex01_test
	Capture DriveToFile	EX01	16gb	16GB	${true}	${UNIT}/ex01_test
	Push Capture  ${CDST}	${UNIT}/ex01_test	${PDST}	${UNIT}/ex01_push_test

IMAGE_CAPTURE_DD_DMG
	Capture DriveToFile	DD	2gb	2GB	${false}	${UNIT}/ddmg_test
	Capture DriveToFile	DMG	4gb	4GB	${false}	${UNIT}/ddmg_test
	Capture DriveToFile	DD	8gb	8GB	${false}	${UNIT}/ddmg_test
	Capture DriveToFile	DMG	16gb	16GB	${false}	${UNIT}/ddmg_test
	Push Capture  ${CDST}	${UNIT}/ddmg_test	${PDST}	${UNIT}/ddmg_push_test
