*** Settings ***
Documentation     Sample test cases to develop framework/library
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Capture Screen On Failure
Suite Teardown    Close Ui

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	#Delete All Tasks	Image
	#Delete All Tasks	Wipe
	#Delete All Tasks	Hash
	Delete All Tasks	Push
	#Drop All Checkpoints

TEST_PUSH
	Go To Task	Push:1
	Select Case	Push	Master	SAS_D1	falcon-171000.local/e01_test
	Set Push Verify Mode	YES
	Select Repository Path	Push	Target	nas	falcon-171000.local/e01_push_test

*** Comments ***
IMAGE_F2F_LX01
	[Tags]    no_tag
	Load Remote UI
	Go To Task	Image:1
	Set Imaging Mode	FileToFile
	Select Drives	Image	Master_Source	NAS
	@{dirs}=	Create List	Downloads	Pictures
	Select F2F Source Path	${dirs}
	Set F2F Method	L01
	Set F2F Segment Settings	8GB	${false}
	Select Repository Path	Image	Target	SAS_D2	test4/test5/test6
	#Start Task	Image:1
	#Wait For Task	Image:1

IMAGE_F2F_L01
	[Tags]    no_tag
	Load Remote UI
	Go To Task	Image:1
	Set Imaging Mode	FileToFile
	Select Drives	Image	Master_Source	SAS_S1
	@{dirs}=	Create List	partn-2_FAT32/EFI/Microsoft/Recovery	partn-2_FAT32/System Volume Information/ClientRecoveryPasswordRotation
	Select F2F Source Path	${dirs}
	Set F2F Method	L01
	Set F2F Segment Settings	8GB	${false}
	Select Repository Path	Image	Target	SAS_D2	test4/test5/test6
	Start Task	Image:1
	Wait For Task	Image:1

WIPE_FORMAT_ALL_EXFAT
	[Tags]    no_tag
	Load Remote UI
	Add Tasks	Wipe	1
	Go To Task	Wipe:2
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	EXFAT	False
	Start Task	Wipe:2
	Wait For Task	Wipe:2

IMAGE_D2F
	Go To Task	Image:1
	Set Imaging Mode	DriveToFile
	Select Drives	Image	Master	SAS_S1
	Set Image Hash Method	SHA1	PRIMARY
	Set Image Method	DD	8GB
	Select Repository Path	Image	Target	SAS_D2	test3/test4/test5
	Start Task	Image:1
	Wait For Task	Image:1

IMAGE_F2D
	Add Tasks	Image	1
	Go To Task	Image:2
	Set Imaging Mode	FileToDrive
	Select Case	Image	Master	SAS_D2	test3/test4/test5/DDCapture
	Select Drives	Image	Target	SAS_D1
	Start Task	Image:2
	Wait For Task	Image:2

WIPE_FORMAT_ALL_EXT4
	[Tags]    no_tag
	Load Remote UI
	Add Tasks	Wipe	1
	Go To Task	Wipe:2
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	EXT4	False
	Start Task	Wipe:2
	Wait For Task	Wipe:2

IMAGE_D2F_EX01_2GB_SHA1_NOCOMPRESS_DYNAMIC
	[Tags]    no_tag
	Load Remote UI
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
		Run Keyword If	${task} > 1	Add Tasks	Image	1
		Go To Task	Image:${task}
		Set Imaging Mode	DriveToFile
		Select Drives	Image	Master	${p}[0]
		Set Image Hash Method	SHA1	PRIMARY
		Set Image Method	EX01	2GB
		Set Image Compression	False
		Select Repositories	Image	Target	${p}[1]
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}

	# Wait for all tasks to end
	Wait For Tasks	${tasks}

	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}

*** Comment ***
# TEST CASES IN THE *COMMENT* SECTION ARE NOT EXECUTED

IMAGE_D2F_DD_16G_SHA1
	[Tags]    no_tag
	Load Remote UI
	Go To Task	Image	1
	Set Imaging Mode	DriveToFile
	# Select any drives in source bays that beging with 'SAS_'; so
	# basically SAS_S1 or SAS_S2
	Select Drives	Image	Master	^SAS_
	Set Image Hash Method	SHA1MD5	BOTH
	Set Image Method	DD	16GB
	# Select all repositories in destination bays that beging
	# with 'SAS_'; so basically SAS_D1 or SAS_D2
	Select Repositories	Image	Target	^SAS_
	Start Task	Image	1
	${tasks}=	Create List	Image:1
	Wait For Tasks	${tasks}

IMAGE_D2F_E01_8G_SHA1
	[Tags]    no_tag
	Load Remote UI
	Delete_All_Tasks	Image
	Add Tasks	Image	1
	Go To Task	Image	2
	Set Imaging Mode	DriveToFile
	# Select any drives in source bays that beging with 'SAS_'; so
	# basically SAS_S1 or SAS_S2
	Select Drives	Image	Master	^SAS_
	Set Image Hash Method	SHA1	PRIMARY
	Set Image Method	E01	8GB
	Set Image Compression	False
	# Select all repositories in destination bays that beging
	# with 'SATA_'; so basically SATA_D3 or SATA_D4
	Select Repositories	Image	Target	^SATA_
	Start Task	Image	2
	${tasks}=	Create List	Image:2
	Wait For Tasks	${tasks}

IMAGE_D2D_SHA1_VERIFY
	[Tags]    no_tag
	Load Remote UI
	Add Tasks	Image	2
	Go To Task	Image	2
	Set Imaging Mode	DriveToDrive
	Select Drives	Image	Master	^SAS_
	Select Drives	Image	Target	^SAS_
	Set Clone Hash Method	SHA256	NO
	Start Task	Image	2
	${tasks}=	Create List	Image:2
	Wait For Tasks	${tasks}

HASH_SHA1
	[Tags]    no_tag
	Load Remote UI
	Add Tasks	Hash	3
	Go To Task	Hash	2
	Select Drives	Hash	Target	^SAS_
	Set Hash Task Method	SHA1
	Start Task	Hash	2
	${tasks}=	Create List	Hash:2
	Wait For Tasks	${tasks}

HASH_SHA256_MD5
	[Tags]    no_tag
	Load Remote UI
	Add Tasks	Hash	3
	Go To Task	Hash	2
	Select Drives	Hash	Target	^SAS_
	Set Hash Task Method	SHA256
	Go To Task	Hash	3
	Select Drives	Hash	Target	^SATA_
	Set Hash Task Method	MD5
	Start Task	Hash	2
	Start Task	Hash	3
	${tasks}=	Create List	Hash:2	Hash:3
	Wait For Tasks	${tasks}
